/******************************************************************************/
/* Sistemas Integrados TECNISA                                                */
/*                                                                            */
/* Pedidos e Expedio                                                        */
/*                                                                            */
/******************************************************************************/
/*                                                                            */
/* Nome: 9600_EXPTRG_ATUALIZA_PEDIDO                                          */
/*                                                                            */
/* Descrio:                                                                 */
/* Quando um item da NF gerado pelo Sistema Expedio  excludo, o campo     */
/* QTEXPITEMPED (quantidade expedida) da tabela ITEMPEDIDO  atualizado.      */
/* Se necessrio, a situao do item de pedido e do pedido so atualizados.   */
/*                                                                            */
/* Criao:                                                                   */
/* 09/12/1999 - Rogrio Cosendey Labanca                                      */
/* 23/01/2003 - Alysson Junio de Carvalho(Converso p/ SQLServer)             */
/*                                                                            */
/******************************************************************************/

IF EXISTS(SELECT * FROM sysobjects O, sysusers U
          WHERE o.name = 'ATUALIZA_PEDIDO'  and
                type = 'TR'                 and
                u.uid = o.uid               and
                u.name = USER)

DROP TRIGGER ATUALIZA_PEDIDO
GO

CREATE TRIGGER ATUALIZA_PEDIDO
ON ITEMPRODUTO
FOR DELETE

AS

   DECLARE @V_IDSITITEMPED    VARCHAR(1);
   DECLARE @V_QTEXPITEMPED    FLOAT;
   DECLARE @V_QTITEMPED       FLOAT;
   DECLARE @V_VRPELIQEXP      FLOAT;
   DECLARE @V_OLD_CDFILIALPED VARCHAR(4);
   DECLARE @V_OLD_NRPEDIDO    VARCHAR(10);
   DECLARE @V_OLD_NRITEMPED   VARCHAR(10);
   DECLARE @V_OLD_QTITEMPROD  FLOAT;
   DECLARE @V_QTPARCITEMPED   FLOAT;
   DECLARE @V_NRITENS         INTEGER;
   DECLARE @V_IDGERPRODEST    VARCHAR(1);
   DECLARE @V_VRFATOCONV      FLOAT;
BEGIN
   DECLARE C_ITEMPROD CURSOR FOR
   SELECT CDFILIALPED, NRPEDIDO, NRITEMPED, QTITEMPROD
   FROM DELETED

   OPEN C_ITEMPROD;

   FETCH NEXT FROM C_ITEMPROD INTO @V_OLD_CDFILIALPED, @V_OLD_NRPEDIDO, @V_OLD_NRITEMPED, @V_OLD_QTITEMPROD;

   WHILE (@@FETCH_STATUS = 0) BEGIN
      IF ((NOT (@V_OLD_CDFILIALPED IS NULL)) AND
          (NOT (@V_OLD_NRPEDIDO    IS NULL)) AND
          (NOT (@V_OLD_NRITEMPED   IS NULL))) BEGIN

         SELECT @V_IDGERPRODEST = MAX(IDGERPRODEST)
         FROM PAREXPEDICAO
         WHERE CDFILIAL = @V_OLD_CDFILIALPED;

         SELECT @V_IDSITITEMPED = MAX(I.IDSITITEMPED), @V_QTEXPITEMPED = MAX(I.QTEXPITEMPED),
                @V_QTITEMPED    = MAX(I.QTITEMPED),    @V_VRPELIQEXP   = MAX(P.VRPELIQEXP)
         FROM ITEMPEDIDO I, PAREXPEDICAO P
         WHERE ((@V_OLD_CDFILIALPED = I.CDFILIAL)    AND
                (@V_OLD_NRPEDIDO    = I.NRPEDIDO)    AND
                (@V_OLD_NRITEMPED   = I.NRITEMPED)   AND
                (@V_OLD_CDFILIALPED = P.CDFILIAL));

         IF (@V_IDGERPRODEST = '1') BEGIN
            IF (@V_QTEXPITEMPED - @V_OLD_QTITEMPROD) >= 0 BEGIN
               SET @V_QTPARCITEMPED = (@V_QTEXPITEMPED - @V_OLD_QTITEMPROD);
               UPDATE ITEMPEDIDO
               SET QTEXPITEMPED = (@V_QTEXPITEMPED - @V_OLD_QTITEMPROD)
               WHERE ((@V_OLD_CDFILIALPED = CDFILIAL)    AND
                      (@V_OLD_NRPEDIDO    = NRPEDIDO)    AND
                      (@V_OLD_NRITEMPED   = NRITEMPED));
            END
            ELSE BEGIN
               SET @V_QTPARCITEMPED = 0;
               UPDATE ITEMPEDIDO
               SET QTEXPITEMPED = 0
               WHERE ((@V_OLD_CDFILIALPED = CDFILIAL)    AND
                      (@V_OLD_NRPEDIDO    = NRPEDIDO)    AND
                      (@V_OLD_NRITEMPED   = NRITEMPED));
            END;
         END
         ELSE BEGIN
            IF (@V_IDGERPRODEST = '2') BEGIN
               SELECT @V_VRFATOCONV = MAX(A.VRFATOCONV)
               FROM PRODUTO A, ITEMPEDIDO I
               WHERE ((A.CDPRODUTO      = I.CDPRODUTO) AND
                      (@V_OLD_CDFILIALPED = I.CDFILIAL ) AND
                      (@V_OLD_NRPEDIDO    = I.NRPEDIDO ) AND
                      (@V_OLD_NRITEMPED   = I.NRITEMPED));

               IF @V_VRFATOCONV IS NULL BEGIN
                  SET @V_VRFATOCONV = 0;
               END;

               IF (@V_VRFATOCONV <> 0) BEGIN
                  IF (@V_QTEXPITEMPED - (@V_OLD_QTITEMPROD / @V_VRFATOCONV)) >= 0 BEGIN
                     SET @V_QTPARCITEMPED = (@V_QTEXPITEMPED - (@V_OLD_QTITEMPROD / @V_VRFATOCONV));
                     UPDATE ITEMPEDIDO
                     SET QTEXPITEMPED = (@V_QTEXPITEMPED - (@V_OLD_QTITEMPROD / @V_VRFATOCONV))
                     WHERE ((@V_OLD_CDFILIALPED = CDFILIAL)    AND
                            (@V_OLD_NRPEDIDO    = NRPEDIDO)    AND
                            (@V_OLD_NRITEMPED   = NRITEMPED));
                  END
                  ELSE BEGIN
                     SET @V_QTPARCITEMPED = 0;

                     UPDATE ITEMPEDIDO
                     SET QTEXPITEMPED = 0
                     WHERE ((@V_OLD_CDFILIALPED = CDFILIAL)    AND
                            (@V_OLD_NRPEDIDO    = NRPEDIDO)    AND
                            (@V_OLD_NRITEMPED   = NRITEMPED));
                  END;
               END
               ELSE BEGIN
                  IF (@V_QTEXPITEMPED - @V_OLD_QTITEMPROD) >= 0 BEGIN
                     SET @V_QTPARCITEMPED = (@V_QTEXPITEMPED - @V_OLD_QTITEMPROD);

                     UPDATE ITEMPEDIDO
                     SET @V_QTPARCITEMPED = (@V_QTEXPITEMPED - @V_OLD_QTITEMPROD)
                     WHERE ((@V_OLD_CDFILIALPED = CDFILIAL)    AND
                            (@V_OLD_NRPEDIDO    = NRPEDIDO)    AND
                            (@V_OLD_NRITEMPED   = NRITEMPED));
                  END
                  ELSE BEGIN
                     SET  @V_QTPARCITEMPED = 0;
                     UPDATE ITEMPEDIDO
                     SET QTEXPITEMPED = 0
                     WHERE ((@V_OLD_CDFILIALPED = CDFILIAL)    AND
                            (@V_OLD_NRPEDIDO    = NRPEDIDO)    AND
                            (@V_OLD_NRITEMPED   = NRITEMPED));
                  END;
               END;
            END
            ELSE BEGIN
               IF(@V_IDGERPRODEST = '3')BEGIN
                  SET  @V_QTPARCITEMPED = 0;
                  UPDATE ITEMPEDIDO
                  SET QTEXPITEMPED = 0
                  WHERE ((@V_OLD_CDFILIALPED = CDFILIAL)    AND
                        (@V_OLD_NRPEDIDO    = NRPEDIDO)    AND
                        (@V_OLD_NRITEMPED   = NRITEMPED));
               END
            END;
         END;

         SET @V_NRITENS = 0;
         IF(@V_IDSITITEMPED = '4')OR(@V_IDSITITEMPED = '6')OR(@V_IDSITITEMPED = '7')BEGIN
            IF (@V_QTPARCITEMPED = 0) BEGIN
               UPDATE ITEMPEDIDO
               SET IDSITITEMPED = '3'
               WHERE ((@V_OLD_CDFILIALPED = CDFILIAL)    AND
                      (@V_OLD_NRPEDIDO    = NRPEDIDO)    AND
                      (@V_OLD_NRITEMPED   = NRITEMPED));

               SELECT @V_NRITENS = COUNT(*)
               FROM ITEMPEDIDO
               WHERE
                     (CDFILIAL =  @V_OLD_CDFILIALPED)
                  AND(NRPEDIDO =  @V_OLD_NRPEDIDO)
                  AND(QTEXPITEMPED <> 0);

               IF (@V_NRITENS =  0) BEGIN
                  UPDATE PEDIDO
                  SET IDSITPEDIDO = '2'
                  WHERE
                     ((@V_OLD_CDFILIALPED = CDFILIAL)AND
                      (@V_OLD_NRPEDIDO    = NRPEDIDO));
               END
               ELSE BEGIN
                  UPDATE PEDIDO
                  SET IDSITPEDIDO = '6'
                  WHERE
                     ((@V_OLD_CDFILIALPED = CDFILIAL)AND
                      (@V_OLD_NRPEDIDO    = NRPEDIDO));
               END;

               INSERT INTO HISITEMPED
               (CDFILIAL, NRPEDIDO, NRITEMPED, DTHRHIST, IDSITATUHIST, IDSITANTHIST, IDALTHISTITE)
               VALUES
               (@V_OLD_CDFILIALPED, @V_OLD_NRPEDIDO, @V_OLD_NRITEMPED, GETDATE(), '3', @V_IDSITITEMPED, '1');
            END
            ELSE BEGIN
               IF( @V_IDSITITEMPED <> '7')BEGIN
                  UPDATE ITEMPEDIDO
                  SET IDSITITEMPED = '7'
                  WHERE ((@V_OLD_CDFILIALPED = CDFILIAL)    AND
                         (@V_OLD_NRPEDIDO    = NRPEDIDO)    AND
                         (@V_OLD_NRITEMPED   = NRITEMPED));

                  UPDATE PEDIDO
                  SET IDSITPEDIDO = '6'
                  WHERE ((@V_OLD_CDFILIALPED = CDFILIAL)AND
                         (@V_OLD_NRPEDIDO    = NRPEDIDO));

                  INSERT INTO HISITEMPED
                  (CDFILIAL, NRPEDIDO, NRITEMPED, DTHRHIST, IDSITATUHIST, IDSITANTHIST, IDALTHISTITE)
                  VALUES
                  (@V_OLD_CDFILIALPED, @V_OLD_NRPEDIDO, @V_OLD_NRITEMPED, GETDATE(), '7', @V_IDSITITEMPED, '1');
               END;
            END;
         END;
      END;
      FETCH NEXT FROM C_ITEMPROD INTO @V_OLD_CDFILIALPED, @V_OLD_NRPEDIDO, @V_OLD_NRITEMPED, @V_OLD_QTITEMPROD;
   END;
   CLOSE C_ITEMPROD;
   DEALLOCATE C_ITEMPROD;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'ATUALIZA_PEDIDO','4.11.165';
GO



